==> igniteui-webcomponents-core-4.0.2.tgz: package/esm2015/lib/WebNumberEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebNumberEventArgsDescription } from "./WebNumberEventArgsDescription";
/**
 * @hidden
 */
export let WebNumberEventArgsDescriptionMetadata = /*@__PURE__*/ (() => {
    class WebNumberEventArgsDescriptionMetadata extends Base {
        static b(a) {
            if (WebNumberEventArgsDescriptionMetadata.a == null) {
                WebNumberEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                WebNumberEventArgsDescriptionMetadata.c(WebNumberEventArgsDescriptionMetadata.a);
            }
            if (a.j(WebNumberEventArgsDescriptionMetadata.a)) {
                return;
            }
            a.y(WebNumberEventArgsDescriptionMetadata.a);
        }
        static c(a) {
            a.item("__qualifiedNameTS", "String:NumberEventArgs");
            a.item("Detail", "Number:double");
        }
        static d(a) {
            WebNumberEventArgsDescriptionMetadata.b(a);
            a.aa("WebNumberEventArgs", () => new WebNumberEventArgsDescription());
            a.z("WebNumberEventArgs", WebNumberEventArgsDescriptionMetadata.a);
        }
    }
    WebNumberEventArgsDescriptionMetadata.$t = /*@__PURE__*/ markType(WebNumberEventArgsDescriptionMetadata, 'WebNumberEventArgsDescriptionMetadata');
    WebNumberEventArgsDescriptionMetadata.a = null;
    return WebNumberEventArgsDescriptionMetadata;
})();

==> igniteui-webcomponents-core-4.2.5.tgz: package/esm2015/lib/WebNumberEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebNumberEventArgsDescription } from "./WebNumberEventArgsDescription";
/**
 * @hidden
 */
export let WebNumberEventArgsDescriptionMetadata = /*@__PURE__*/ (() => {
    class WebNumberEventArgsDescriptionMetadata extends Base {
        static b(a) {
            if (WebNumberEventArgsDescriptionMetadata.a == null) {
                WebNumberEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                WebNumberEventArgsDescriptionMetadata.c(WebNumberEventArgsDescriptionMetadata.a);
            }
            if (a.k(WebNumberEventArgsDescriptionMetadata.a)) {
                return;
            }
            a.aa(WebNumberEventArgsDescriptionMetadata.a);
        }
        static c(a) {
            a.item("__qualifiedNameTS", "String:NumberEventArgs");
            a.item("__skipModuleRegisterWebComponents", "Boolean");
            a.item("__importTypesWebComponents", "String:igniteui-webcomponents");
            a.item("Detail", "Number:double");
        }
        static d(a) {
            WebNumberEventArgsDescriptionMetadata.b(a);
            a.ac("WebNumberEventArgs", () => new WebNumberEventArgsDescription());
            a.ab("WebNumberEventArgs", WebNumberEventArgsDescriptionMetadata.a);
        }
    }
    WebNumberEventArgsDescriptionMetadata.$t = /*@__PURE__*/ markType(WebNumberEventArgsDescriptionMetadata, 'WebNumberEventArgsDescriptionMetadata');
    WebNumberEventArgsDescriptionMetadata.a = null;
    return WebNumberEventArgsDescriptionMetadata;
})();
